<?php

/**
 * Plugin Name:       GF Forms LeadsBridge Add-On
 * Description:       Submits Gravity Forms form data to LeadsBridge.
 * Version:           1.0.2
 * Author:            Thomas Cocchiara
 * Author URI:        mailto:thomas.cocchiara@gmail.com
 * Text Domain:       gravityformsleadsbridge
 */

// Include our handler(s).
// These functions will send the form data over HTTP POST to a remote URL.
require_once('includes/post-actions.php');

// Only register this plugin's functionality if Gravity Forms is installed
// and the required hook exists.
if (has_action('gform_after_submission')) {
	// Hook Gravity forms on form submit.
	add_action('gform_after_submission', 'gf_post_to_lb', 10, 2);

	// Admin menu and links for the plugin.
	add_action('admin_menu', 'gravity_forms_leadsbridge_submenu', 11);
}

// Adds GUI stuff to the WP Admin backend. Place our plugin's options under Gravity Forms menu.
function gravity_forms_leadsbridge_submenu() {
	// Check user/admin permissions.
	if (!current_user_can('edit_pages')) {
		return;
	}

	add_submenu_page(
		'gf_edit_forms',
		'Gravity Forms to LeadsBridge',
		'LeadsBridge',
		'edit_pages',
		'gflb',
		'gflb_settings_page'
	);
}

// Admin page/form and handler.
function gflb_settings_page() {
	// Check user/admin permissions.
	if (!current_user_can('edit_pages')) {
		wp_die(esc_html(__('You do not have sufficient permissions to access this page.')));
	}

	if (isset($_POST['nonce'])) {
		if ($_POST['action'] === 'gflb_create_webhook' &&
			wp_verify_nonce($_POST['nonce'], 'gflb_create_webhook')) {

			$validated = true;
			$error = "";

			foreach ($_POST as $key => $value) {
				$value = sanitize_text_field($value);
				$key = sanitize_text_field($key);

				if (strpos($key, 'gflb_') !== false) {
					if (strpos($key, 'gflb_form_post_url__') !== false) {
						if (!empty($value) && strpos($value, 'https://leadsbridge.com/app/webhook/') === false) {
							$validated = false;
							$error = "Webhook $value is not a valid LeadsBridge webhook";
						}
					} else {
						if (!is_numeric($value)) {
							$validated = false;
							$error = "Form ID $value is not a valid ID, the form ID should be numeric";
						}
					}

					if (!$validated) {
						break;
					}

					update_option($key, $value);
				}
			}

			if ($validated) {
				echo '<div class="updated"><p><strong>' . esc_html(__("Settings Saved")) . '.</strong></p></div>';
			} else {
				echo '<div class="error"><p><strong>' . esc_html(__($error)) . '.</strong></p></div>';
			}
		} else {
			wp_die(esc_html(__('You do not have sufficient permissions to access this page.')));
		}
	}

	echo '<h1>' . _("GF Forms to LeadsBridge") . '</h1>';
	echo '<form name="gflb_ids" method="post" action="">';

	echo '<fieldset>';


	$formsExist = false;

	foreach (GFAPI::get_forms() as $form) {
		$formsExist = true;
		$i = $form['id'];

		echo '<input type="hidden" name="gflb_formID__'.$i.'" value="' . $i . '" size="2">';

		echo '<label for="gflb_form_post_url__'.$i.'">' . esc_html(__("LeadsBridge Webhook URL for form")) . ' <b>'. $form['title'] .'</b>: </label> <input style="width: 50%" type="text" name="gflb_form_post_url__' . $i . '" value="' . get_option("gflb_form_post_url__$i") . '">';
		echo '<br><br>';
	}

	echo '<input type="hidden" name="nonce" value="' . wp_create_nonce('gflb_create_webhook') . '" />';
	echo '<input type="hidden" name="action" value="gflb_create_webhook" />';

	echo '</fieldset>';

	if ($formsExist) {
		echo '<hr />';
		echo '<input type="submit" name="Submit" class="button-primary" value="Save Changes" />';
	} else {
		echo '<div><p><strong>' . esc_html(__("There are no active forms yet, please create at least one")) . '.</strong></p></div>';
	}

	echo '</form>';
}
